@@ -1,17 +1,19 @@
 """Pull the latest version of the Dodo Commands system."""
-from argparse import ArgumentParser
-from dodo_commands.framework import Dodo, CommandError
-from dodo_commands.framework.config import ConfigIO
-from dodo_commands.framework.util import symlink
 import glob
 import os
 import sys
+from argparse import ArgumentParser
+
+from dodo_commands import CommandError, Dodo
+from dodo_commands.framework.config_io import ConfigIO
+from dodo_commands.framework.paths import Paths
+from dodo_commands.framework.util import query_yes_no, symlink
 
 
 def _args():
     parser = ArgumentParser()
-    parser.add_argument(
-        'src_dir', help="The src directory for the bootstrapped project")
+    parser.add_argument('src_dir',
+                        help="The src directory for the bootstrapped project")
     parser.add_argument(
         'shared_config_dir',
         help=
@@ -39,8 +41,10 @@ def _args():
         help="Use cookiecutter to create the src_dir location",
     )
 
-    parser.add_argument(
-        '--depth', type=int, default=0, help="Depth for cloning repositories")
+    parser.add_argument('--depth',
+                        type=int,
+                        default=0,
+                        help="Depth for cloning repositories")
     parser.add_argument('--branch', help="Branch to checkout after cloning")
 
     parser.add_argument(
@@ -58,13 +62,14 @@ def _report(msg):
 
 
 def _copy_defaults(args, shared_config_dir):
-    res_dir = os.path.join(args.project_dir, "dodo_commands", "res")
+    config_dir = os.path.join(args.project_dir, ".dodo_commands")
     for filename in glob.glob(os.path.join(shared_config_dir, "*")):
-        dest_path = os.path.join(res_dir, os.path.basename(filename))
+        dest_path = os.path.join(config_dir, os.path.basename(filename))
         if os.path.exists(dest_path):
             if args.confirm:
                 print(
-                    "Warning, destination path already exists: %s" % dest_path)
+                    "Warning, destination path already exists: %s. Overwrite it?"
+                    % dest_path)
             elif args.use_force:
                 print("Overwriting existing path: %s" % dest_path)
             else:
@@ -76,30 +81,29 @@ def _copy_defaults(args, shared_config_dir):
 
 def _clone(args, src_dir):
     if os.path.exists(src_dir):
-        raise CommandError(
-            "Cannot clone into %s, path already exists" % src_dir)
+        raise CommandError("Cannot clone into %s, path already exists" %
+                           src_dir)
 
-    Dodo.run(
-        ["git", "clone", args.git_url,
-         os.path.basename(src_dir)] + (["--depth", args.depth]
-                                       if args.depth else []),
-        cwd=os.path.dirname(src_dir))
+    Dodo.run(["git", "clone", args.git_url,
+              os.path.basename(src_dir)] +
+             (["--depth", args.depth] if args.depth else []),
+             cwd=os.path.dirname(src_dir))
     if args.branch:
         Dodo.run(["git", "checkout", args.branch], cwd=src_dir)
 
 
 def _cookiecutter(src_dir, cookiecutter_url):
     if os.path.exists(src_dir):
-        raise CommandError(
-            "Cannot clone into %s, path already exists" % src_dir)
+        raise CommandError("Cannot clone into %s, path already exists" %
+                           src_dir)
 
     Dodo.run(["cookiecutter", cookiecutter_url, "-o", src_dir])
 
 
 def _link_dir(link_target, link_name):
     if os.path.exists(link_name):
-        raise CommandError(
-            "Cannot create a link because %s already exists" % link_name)
+        raise CommandError("Cannot create a link because %s already exists" %
+                           link_name)
     if os.name == 'nt' and not args.confirm:
         symlink(link_target, link_name)
     else:
@@ -107,20 +111,36 @@ def _link_dir(link_target, link_name):
 
 
 def _update_config(src_dir, relative_shared_config_dir):
-    config = ConfigIO().load(load_layers=False)
-    config['ROOT']['src_dir'] = src_dir
-    config['ROOT'][
-        'shared_config_dir'] = '${/ROOT/src_dir}/%s' % relative_shared_config_dir
-    ConfigIO().save(config)
+    config_file = os.path.join(Paths().config_dir(), "config.yaml")
+
+    if args.confirm:
+        print("Update the key /ROOT/src_dir in your configuration file (%s)" %
+              config_file)
+
+    if not args.confirm or query_yes_no("confirm?"):
+        config = ConfigIO().load()
+        config['ROOT']['src_dir'] = src_dir
+        ConfigIO().save(config)
+
+    if args.confirm:
+        print(
+            "Update the key /ROOT/shared_config_dir in your configuration file (%s)"
+            % config_file)
+
+    if not args.confirm or query_yes_no("confirm?"):
+        config = ConfigIO().load()
+        config['ROOT'][
+            'shared_config_dir'] = '${/ROOT/src_dir}/%s' % relative_shared_config_dir
+        ConfigIO().save(config)
 
 
 def _get_full_src_dir(src_dir, src_subdir):
-    postfix = (os.path.join(src_dir, src_subdir) if src_subdir else src_dir)
-    return (postfix if os.path.isabs(src_dir) else os.path.join(
-        args.project_dir, postfix))
+    postfix = os.path.join(src_dir, src_subdir) if src_subdir else src_dir
+    return (postfix if os.path.isabs(src_dir) else os.path.abspath(
+        os.path.join(args.project_dir, postfix)))
 
 
-if Dodo.is_main(__name__, safe=False):
+if Dodo.is_main(__name__, safe=True):
     args = _args()
 
     full_src_dir = _get_full_src_dir(args.src_dir, args.src_subdir)
@@ -136,7 +156,7 @@ if Dodo.is_main(__name__, safe=False):
     shared_config_dir = os.path.join(full_src_dir, args.shared_config_dir)
     if not os.path.exists(shared_config_dir):
         if args.create_scd:
-            os.makedirs(shared_config_dir)
+            Dodo.run(['mkdir', '-p', shared_config_dir])
         else:
             raise CommandError(
                 "Shared configuration directory %s does not exist. Hint: use --create-scd."
